@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use English qw(-no_match_vars);
 
-our $VERSION = '1.20';
+our $VERSION = '1.21';
 
 use Carp;
 use Getopt::Long;
@@ -190,6 +190,10 @@ sub transform_test_specs {
         # It's a substitution if it has no other meaning.
         if (defined $5) {
           my $var = $1;
+          # Check if the variable name needs to be substituted.
+          if ($var =~ /$in_or_out_bracketed/) {
+            next if $self->_queue_substituted_lines($_);
+          }
           my @data = $self->expand_backticked($5);
           my ($status, $message) = $self->_check_dependencies($var, @data);
           if ($status) {
@@ -411,11 +415,6 @@ sub _find_substitutions {
   my %unique_vars = map {$_ => 1} @vars;
   @vars = keys %unique_vars;
 
-  # @vars may now include things like variables we've forgotten and 
-  # HTML tags. Discard these guys. If nothing's left, bow out.
-  @vars = grep { $self->_subs->{$_} } @vars;
-  return unless @vars;
-
   # Each variable may (possibly) contain nested variable references.
   # If we find one of these, do the substitutions to remove the nesting
   # and add the newly-generated variable names to the list of variables.
@@ -426,9 +425,8 @@ sub _find_substitutions {
     my $var = shift @vars;
     my @nested_vars = $self->_find_substitutions($var);
     if (@nested_vars) {
-      for my $possible_new ($self->_substitute($var, @nested_vars)) {
-        # Don't reprocess variables we've already checked out.
-        push @vars, $possible_new unless exists $expanded_vars{$possible_new};
+      foreach my $nested_var (@nested_vars) {
+        $expanded_vars{$nested_var}++; 
       }
     }
     else {
@@ -438,28 +436,9 @@ sub _find_substitutions {
   }
 
   # After we've bottomed out, we've got the list of all possible variables
-  # we might substitute in. We now need to know what variables the values of
-  # these variables may depend on as well.
-  my %dependencies;
-
-  # Get the unique variables generated by the previous search over the 
-  # variables to be substituted (and their dependencies).
-  @vars = keys %expanded_vars;
-  while (@vars) {
-    my $var = shift @vars;
-
-    # Each value gets run through _find_substitutions, so we can find the 
-    # variables it depends on.
-    my $value = $self->_subs->{$var};
-    next unless $value;
-
-    # Add any variables that need to be substituted into the value to
-    # the set of dependencies.
-    for my $dependency ($self->_find_substitutions($value)) {
-      $dependencies{$dependency}++;
-    }
-  }
-  return (keys %expanded_vars, keys %dependencies);
+  # we might substitute in. Remove variables with no substitution values.
+  @vars = grep { $self->_subs->{$_} } keys %expanded_vars;
+  return @vars;
 }
 
 sub _expand_variables {
